whatsthedamage.api.v2 package
=============================

.. automodule:: whatsthedamage.api.v2
   :members:
   :show-inheritance:
   :undoc-members:

Submodules
----------

whatsthedamage.api.v2.endpoints module
--------------------------------------

.. automodule:: whatsthedamage.api.v2.endpoints
   :members:
   :show-inheritance:
   :undoc-members:

whatsthedamage.api.v2.schema module
-----------------------------------

.. automodule:: whatsthedamage.api.v2.schema
   :members:
   :show-inheritance:
   :undoc-members:
